# How to Contribute

This is a very young project, and the codebase is moving quickly -- but there are plenty of ways to help.

## Ask questions and file issues

Please use the Github issue tracker for all issues with, and questions about, the project. 

If you have any questions, please file an issue and we'll answer it as soon as we can. Make your question or issue
clear in the title, and be sure to look through the issues just in case someone else has asked the same questions.

## Pull requests

Pull requests are always welcome. We may not necessarily accept them, but we will happy to discuss them with you.

## Provide examples

Examples of working Ansible Container playbooks will be very useful! Please feel free to provide Pull Requests linking
to examples from your own repos in [EXAMPLES.md](./EXAMPLES.md).

Thanks for trying out Ansible Container!
